summaryrefslogtreecommitdiff
path: root/src/cygw32.h
diff options
context:
space:
mode:
authorEli Zaretskii <eliz@gnu.org>2012-10-08 11:52:25 +0200
committerEli Zaretskii <eliz@gnu.org>2012-10-08 11:52:25 +0200
commitbb84afd5709ffae6ddec82ed7b5867912e34cba5 (patch)
treef49be1a75e444ff5a1c2e0eeed84a3fc961ee638 /src/cygw32.h
parent245dc6da184da2bde51055912fafedf714a1a74a (diff)
downloademacs-bb84afd5709ffae6ddec82ed7b5867912e34cba5.tar.gz
Fix comments in src/cygw32.h.
Diffstat (limited to 'src/cygw32.h')
-rw-r--r--src/cygw32.h9
1 files changed, 4 insertions, 5 deletions
diff --git a/src/cygw32.h b/src/cygw32.h
index 4b87b92dd24..22b6f5692da 100644
--- a/src/cygw32.h
+++ b/src/cygw32.h
@@ -38,13 +38,12 @@ along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>. */
/* Access the wide-character string stored in a Lisp string object. */
#define WCSDATA(x) ((wchar_t *) SDATA (x))
-/* Convert the Emacs string in STR to UTF-16LE and store a new string
- containing the encoded version of STR into *BUF. BUF may safely
- point to STR on entry. */
+/* Convert the multi-byte string in STR to UTF-16LE encoded unibyte
+ string, and store it in *BUF. BUF may safely point to STR on entry. */
extern wchar_t *to_unicode (Lisp_Object str, Lisp_Object *buf);
-/* Convert STR, a UTF-16LE encoded string embedded in an Emacs string
- object, to a normal Emacs string and return it. */
+/* Convert STR, a UTF-16LE encoded string embedded in a unibyte string
+ object, to a multi-byte Emacs string, and return it. */
extern Lisp_Object from_unicode (Lisp_Object str);
/* *** Path conversion. *** */